src/hotspot/share/interpreter/interpreterRuntime.cpp
changeset 51444 3e5d28e6de32
parent 51170 7410cb248bbf
child 51467 12997ebbc0d8
--- a/src/hotspot/share/interpreter/interpreterRuntime.cpp	Mon Aug 20 10:04:00 2018 +0200
+++ b/src/hotspot/share/interpreter/interpreterRuntime.cpp	Mon Aug 20 08:25:57 2018 -0400
@@ -924,11 +924,11 @@
            info.call_kind() == CallInfo::vtable_call, "");
   }
 #endif
   // Get sender or sender's host_klass, and only set cpCache entry to resolved if
   // it is not an interface.  The receiver for invokespecial calls within interface
   // methods must be checked for every call.
   InstanceKlass* sender = pool->pool_holder();
-  sender = sender->has_host_klass() ? sender->host_klass() : sender;
+  sender = sender->is_unsafe_anonymous() ? sender->unsafe_anonymous_host() : sender;
 
   switch (info.call_kind()) {
   case CallInfo::direct_call:
@@ -924,11 +924,11 @@
   }
 #endif
-  // Get sender or sender's host_klass, and only set cpCache entry to resolved if
+  // Get sender or sender's unsafe_anonymous_host, and only set cpCache entry to resolved if
   // it is not an interface.  The receiver for invokespecial calls within interface
   // methods must be checked for every call.